==> nextcloud-18.0.4.tgz: nextcloud/apps/comments/l10n/ja.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "コメント",
    "You commented" : "コメント済",
    "%1$s commented" : "%1$s がコメントを追加",
    "{author} commented" : "{author} がコメントしました",
    "You commented on %1$s" : "%1$s にコメントしました",
    "You commented on {file}" : "{file} にコメントしました",
    "%1$s commented on %2$s" : "%2$s について、%1$s がコメントしました",
    "{author} commented on {file}" : "{author} が{file} にコメントしました",
    "<strong>Comments</strong> for files" : "ファイルへの<strong>コメント</strong>があったとき",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "削除されたユーザーのコメントで \"{file}\" にあなたに言及しました",
    "{user} mentioned you in a comment on “{file}”" : "{user} さんが ““{file}” のコメントであなたについて言及しました。",
    "Files app plugin to add comments to files" : "ファイルにコメントを追加するためのファイルアプリプラグイン",
    "Edit comment" : "コメントを編集",
    "Delete comment" : "コメントを削除",
    "New comment …" : "新しいコメント...",
    "Post" : "追加",
    "Cancel" : "キャンセル",
    "[Deleted user]" : "[削除済みユーザー]",
    "No comments yet, start the conversation!" : "まだコメントはありません、会話を開始してください！",
    "More comments …" : "その他のコメント...",
    "Save" : "保存",
    "Allowed characters {count} of {max}" : "入力文字数  {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "ID {id} のコメント取得中にエラーが発生しました",
    "Error occurred while updating comment with id {id}" : "ID {id} のコメント更新中にエラーが発生しました",
    "Error occurred while posting comment" : "コメント投稿中にエラーが発生しました",
    "_%n unread comment_::_%n unread comments_" : ["%n の未読のコメント"],
    "_1 new comment_::_{unread} new comments_" : ["の未読のコメント {unread}"],
    "Comment" : "コメント"
},
"nplurals=1; plural=0;");

==> nextcloud-22.2.1.tgz: nextcloud/apps/comments/l10n/ja.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "コメント",
    "You commented" : "コメント済",
    "%1$s commented" : "%1$s がコメントを追加",
    "{author} commented" : "{author} がコメントしました",
    "You commented on %1$s" : "%1$s にコメントしました",
    "You commented on {file}" : "{file} にコメントしました",
    "%1$s commented on %2$s" : "%2$s について、%1$s がコメントしました",
    "{author} commented on {file}" : "{author} が{file} にコメントしました",
    "<strong>Comments</strong> for files" : "ファイルへの<strong>コメント</strong>があったとき",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "削除されたユーザーのコメントで \"{file}\" にあなたに言及しました",
    "{user} mentioned you in a comment on “{file}”" : "{user} さんが ““{file}” のコメントであなたについて言及しました。",
    "Files app plugin to add comments to files" : "ファイルにコメントを追加するためのファイルアプリプラグイン",
    "Edit comment" : "コメントを編集",
    "Delete comment" : "コメントを削除",
    "Cancel edit" : "編集をキャンセル",
    "Post comment" : "コメントを投稿",
    "No comments yet, start the conversation!" : "まだコメントはありません、会話を開始してください！",
    "No more messages" : "これ以上のメッセージはありません",
    "Retry" : "再試行",
    "Unable to load the comments list" : "コメントリストを読み込めませんでした",
    "_%n unread comment_::_%n unread comments_" : ["%n の未読のコメント"],
    "_1 new comment_::_{unread} new comments_" : ["の未読のコメント {unread}"],
    "Comment" : "コメント",
    "An error occurred while trying to edit the comment" : "コメント編集中にエラーが発生しました",
    "Comment deleted" : "コメントが削除されました",
    "An error occurred while trying to delete the comment" : "コメントの削除中にエラーが発生しました",
    "An error occurred while trying to create the comment" : "コメント中にエラーが発生しました",
    "New comment …" : "新しいコメント...",
    "Post" : "追加",
    "Cancel" : "キャンセル",
    "[Deleted user]" : "[削除済みユーザー]",
    "More comments …" : "その他のコメント...",
    "Save" : "保存",
    "Allowed characters {count} of {max}" : "入力文字数  {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "ID {id} のコメント取得中にエラーが発生しました",
    "Error occurred while updating comment with id {id}" : "ID {id} のコメント更新中にエラーが発生しました",
    "Error occurred while posting comment" : "コメント投稿中にエラーが発生しました"
},
"nplurals=1; plural=0;");
